#
# spec file for package apulse
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define __provides_exclude_from ^%{_libdir}/apulse/.*.so.*$
Name:           apulse
Version:        0.1.12
Release:        2.1
Summary:        PulseAudio emulation for ALSA
License:        MIT
Group:          System/Libraries
URL:            https://github.com/i-rinat/apulse
Source0:        https://github.com/i-rinat/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Source2:        %{name}.py
Source3:        %{name}.conf
# PATCH-FIX-OPENSUSE apulse-fix-pulse-12.patch sor.alexei@meowr.ru -- Fix PulseAudio 12+ compatibility.
Patch0:         apulse-fix-pulse-12.patch
Patch1:         apulse-alsa.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libpulse) >= 5.0
%if %{?_lib} == lib64
Recommends:     %{name}-32bit = %{version}
%endif

%description
PulseAudio emulation intended to be used with Firefox and Skype.

%prep
%autosetup -p1

%build
%cmake \
  -DUSE_BUNDLED_PULSEAUDIO_HEADERS=OFF \
  -DAPULSEPATH=%{_libdir}/%{name}      \
  -DCMAKE_SHARED_LINKER_FLAGS="" -LA
make %{?_smp_mflags} V=1

%install
%cmake_install
rm %{buildroot}%{_libdir}/%{name}/libpulse*.so
install -Dpm 0755 %{SOURCE2} %{buildroot}%{_bindir}/%{name}
install -Dpm 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}.conf

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%if 0%{?suse_version} >= 1500
%license LICENSE.MIT
%else
%doc LICENSE.MIT
%endif
%doc README.md
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_bindir}/%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libpulse*.so.*
%{_mandir}/man1/apulse.1%{?ext_man}

%changelog
* Tue Mar 26 2019 olaf@aepfle.de
- Use alsa API properly. Consumers are expected to use
  <alsa/asoundlib.h> instead of <asoundlib.h>.
  This is in preparation of an change to pkgconfig(alsa) to
  not pollute CFLAGS with -I/usr/include/alsa anymore (bsc#1130333)
  apulse-alsa.patch
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 0.1.12 (changes since 0.1.10):
  * Implement new, free, and write functions of the pa_simple_*
    family.
  * Add some documentation about issues related to sandboxing.
  * Drop the libpulsecommon-5.0.so binary.
  * Add stub functions for the mainloop-glib interface.
  * add a man- page.
  * Cosmetic code changes.
  * Misc compatibility fixes.
- Add apulse-fix-pulse-12.patch sor.alexei@meowr.ru: Fix
  PulseAudio 12+ compatibility.
- Remove apulse-link-math.patch.
- Use %%cmake_install.
- Rewrite the apulse script in Python 3 to avoid insecure config
  reading from home. The apulse.conf format was changed, and the
  user config also was moved from ~/.apulse.conf to
  $XDG_CONFIG_HOME/apulse.conf.
* Mon Mar 12 2018 ilya@ilya.pp.ua
- Refresh spec-file via spec-cleaner.
  * Add %%license macro.
  * Add cmake -LA option for print local variables.
* Wed Jul 19 2017 ilya@ilya.pp.ua
- Add files:
  * apulse.conf
  * apulse (using apulse.conf and autoload 32-bit or 64-bit library)
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 0.1.10 (changes since 0.1.8):
  * Fix the PA_SAMPLE_S16NE volume scaling bug.
  * Fix video stuttering in Firefox by calling write callback as
    soon as minreq bytes become available in write buffer.
  * Make error messages from do_connect_pcm friendlier.
  * Per-stream volumes.
  * Implement source and sink info introspection functions.
  * Implement timed events.
  * Fix buffer xruns by increasing buffer sizes.
* Wed Mar  8 2017 sor.alexei@meowr.ru
- Update to version 0.1.8:
  * Make playback in Firefox working, including volume changing
    (boo#1028547).
  * Reimplement snd_pcm_avail(), which is missing in older versions
    of alsa-lib.
  * Make reported buffer sizes to be multiple of frame sizes.
  * Stop crashing in pa_stream_disconnect() if initialisation has
    failed.
- Add apulse-link-math.patch: Link with -lm to fix building.
* Sat Dec 26 2015 mpluskal@suse.com
- Update to 0.1.7:
  * Make pa_proplist be able to store binary objects too.
  * Implement pa_stream_begin_write.
  * Bugfixes.
* Mon Oct  5 2015 sor.alexei@meowr.ru
- Avoid providing libpulse.so in apulse-32bit.
* Thu Aug 20 2015 sor.alexei@meowr.ru
- Initial package.
